@@ -3,7 +3,15 @@ from .decidir_sdk.DecidirSDK import DecidirSDK
 
 
 class SDK:
-    def __init__(self, merchant):
+    def __init__(self, merchant:dict,processor:str=None):
+        # Si se le indica el procesador
+        if processor == 'mercadopago':
+            self._sdk = MercadoPagoSDK(merchant)
+            pass
+        elif processor == 'decidir':
+            self._sdk = DecidirSDK(merchant)
+            pass
+        # Si no utiliza el preferrred_processor que tenga el merchant
         if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
             self._sdk = DecidirSDK(merchant)
         else:
