@@ -16,9 +16,11 @@ class CardToken:
         }
 
     def create(self, card: dict):
-        card_id = card['decidir_id'] if 'decidir_id' in card else card['id']
+        if 'decidir_id' in card:
+            card['id'] = card['decidir_id']
+
         body = {
-            'token': card_id,
+            'token': card['id'],
             'security_code': '999'
         }
         self.headers['apikey'] = self.public_key
