@@ -16,11 +16,11 @@ class Payment:
             'Cache-Control': 'no-cache'
         }
 
-    def create(self, payment_data: dict, client: dict):
+    def create(self, payment_data: dict):
         body = {
             'customer': {
-                'id': client['decidir_id'],
-                'email': client['email']
+                'id': payment_data['payer']['decidir_id'],
+                'email': payment_data['payer']['email']
             },
             'site_transaction_id': str(uuid4()),  # Debe ser unico? Unico por cliente o por merchant?
             # 'site_id': 28464385, # opcional
@@ -36,11 +36,12 @@ class Payment:
             'sub_payments': []
         }
         r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
+        response = r.json()
+        response['processor'] = 'decidir'
         if r.status_code < 400:
-            response = r.json()
-            response['processor'] = 'decidir'
+            response['status_detail'] = 'ok decidir'
             return ok(response)
-        return error(r.json())
+        return error(response)
 
     def get(self, payment_id: int):
         r = requests.get(self.url + '/payments/{}'.format(payment_id), headers=self.headers)
